==> haskell-data-serializer-0.3.5-287-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-DSoBYJIohtY2jJqiubWkVb
key:                  data-serializer-0.3.5-DSoBYJIohtY2jJqiubWkVb
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  3090aef9e1444f1aaa488889dd9dae68
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-serializer
hs-libraries:         HSdata-serializer-0.3.5-DSoBYJIohtY2jJqiubWkVb
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    parsers-0.12.12-JYJq89eNa6TDPMBJo3uKrQ
    split-0.2.5-8TDPZlIHK1VKb3LgCQDYep

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3.5-288-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-3KavibCOphZ4R9yWGJ8EZf
key:                  data-serializer-0.3.5-3KavibCOphZ4R9yWGJ8EZf
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  bc7bd9f53dc246953ffc3b3245f21067
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-serializer
hs-libraries:         HSdata-serializer-0.3.5-3KavibCOphZ4R9yWGJ8EZf
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    parsers-0.12.12-A4L4eJbdWoQ48Bl9Aan7g7
    split-0.2.5-JwWMTmXvu7fChkavPTERve

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
